MatchMakerMonitoring.must_be_shown — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.must_be_shown

property MatchMakerMonitoring.must_be_shown: bool

  False, if the experiment tolerates skipping this page entirely. Defaults to False.

  Notes

  If there are input elements with force_input=True on a skippable page, particpants will be notified and validation will fail, even if the must_be_shown attribute of the page itself is set to False.

  If a page that must be shown has not been shown, the experiment will display the hint page_must_be_shown as defined in config.conf, section “hints”.

  ..warning::

    It is easy to end up in a situation where a mandatory page has not been shown, but the participant has no way of moving back to it. So, please be careful when using this option.

  Type

    bool